@@ -2,11 +2,10 @@
 
 VERSION=$2
 DIR=jogl-v$VERSION
-TAR=libjogl2-java_$VERSION.orig.tar.xz
+TAR=libjogl2-java_$VERSION+dfsg.orig.tar.xz
 
 # clean up the upstream tarball
-p7zip -d $3
-tar xvf jogl-v$VERSION.tar
+tar xvf $3
 cd $DIR*
 rm -rf .gitignore .htaccess make/lib/ www/
 rm -f src/test/com/jogamp/opengl/test/junit/jogl/demos/es2/shader/landscape.fp
